Index: trunk/psLib/src/sys/psMemory.h
===================================================================
--- trunk/psLib/src/sys/psMemory.h	(revision 4392)
+++ trunk/psLib/src/sys/psMemory.h	(revision 4397)
@@ -12,6 +12,6 @@
  *  @ingroup MemoryManagement
  *
- *  @version $Revision: 1.42 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-25 02:02:05 $
+ *  @version $Revision: 1.43 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-25 03:32:42 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -49,5 +49,5 @@
 
 /// typedef for memory identification numbers.  Guaranteed to be some variety of integer.
-typedef psU64 psMemoryId;
+typedef psU64 psMemId;
 
 /// typedef for a memory block's reference count. Guaranteed to be some variety of integer.
@@ -69,5 +69,5 @@
     psFreeFunc freeFcn;                 ///< deallocator.  If NULL, use generic deallocation.
     size_t userMemorySize;             ///< the size of the user-portion of the memory block
-    const psMemoryId id;               ///< a unique ID for this allocation
+    const psMemId id;               ///< a unique ID for this allocation
     const char *file;                  ///< set from __FILE__ in e.g. p_psAlloc
     const psS32 lineno;                  ///< set from __LINE__ in e.g. p_psAlloc
@@ -84,5 +84,5 @@
  *  @ingroup memCallback
  */
-typedef psMemoryId(*psMemAllocateCallback) (
+typedef psMemId(*psMemAllocateCallback) (
     const psMemBlock* ptr              ///< the psMemBlock just allocated
 );
@@ -93,5 +93,5 @@
  *  @ingroup memCallback
  */
-typedef psMemoryId(*psMemFreeCallback) (
+typedef psMemId(*psMemFreeCallback) (
     const psMemBlock* ptr              ///< the psMemBlock being freed
 );
@@ -259,5 +259,5 @@
  */
 psS32 psMemCheckLeaks(
-    psMemoryId id0,                    ///< don't list blocks with id < id0
+    psMemId id0,                    ///< don't list blocks with id < id0
     psMemBlock* ** arr,                ///< pointer to array of pointers to leaked blocks, or NULL
     FILE * fd,                         ///< print list of leaks to fd (or NULL)
@@ -394,7 +394,7 @@
  *  @ingroup memCallback
  *
- *  @return psMemoryId                 the next memory ID to be used
- */
-psMemoryId psMemGetId(void);
+ *  @return psMemId                 the next memory ID to be used
+ */
+psMemId psMemGetId(void);
 
 /** set p_psMemAllocateID to specific id
@@ -407,10 +407,10 @@
  *  @ingroup memCallback
  *
- *  @return psMemoryId
+ *  @return psMemId
  *
  *  @see psMemAllocateCallbackSet
  */
-psMemoryId psMemAllocateCallbackSetID(
-    psMemoryId id                      ///< ID to set
+psMemId psMemAllocateCallbackSetID(
+    psMemId id                      ///< ID to set
 );
 
@@ -424,10 +424,10 @@
  *  @ingroup memCallback
  *
  *  @return psMemoryId                 the old p_psMemFreeID
  *
  *  @see psMemFreeCallbackSet
  */
-psMemoryId psMemFreeCallbackSetID(
-    psMemoryId id                      ///< ID to set
+psMemId psMemFreeCallbackSetID(
+    psMemId id                      ///< ID to set
 );
 
@@ -424,10 +424,10 @@
  *  @ingroup memCallback
  *
- *  @return psMemoryId                 the old p_psMemFreeID
+ *  @return psMemId                 the old p_psMemFreeID
  *
  *  @see psMemFreeCallbackSet
